Package {QRAGadget}


Version: 0.4
Title: A 'Shiny' Gadget for Interactive 'QRA' Visualizations
Description: Upload raster data and easily create interactive quantitative risk analysis 'QRA' visualizations. Select from numerous color palettes, base-maps, and different configurations.
URL: https://github.com/paulgovan/qragadget, http://paulgovan.github.io/QRAGadget/, https://github.com/paulgovan/QRAGadget
BugReports: https://github.com/paulgovan/QRAGadget/issues
Depends: R (≥ 4.1.0)
License: Apache License version 1.1 | Apache License version 2.0 [expanded from: Apache License]
Encoding: UTF-8
Imports: htmlwidgets, leaflet, miniUI, rhandsontable, scales, shiny, shinyWidgets, terra
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-05 02:35:51 UTC; paulgovan
Author: Paul Govan ORCID iD [aut, cre, cph]
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-05 06:10:23 UTC

A 'Shiny' Gadget for Interactive QRA Visualizations.

Description

Upload raster data and easily create interactive QRA visualizations. Select from numerous color palettes, basemaps, and different configurations.

Usage

QRAGadget()

Value

The function launches a Shiny Gadget.

Examples

if (interactive()) {
  QRAGadget::QRAGadget()
}

mirror server hosted at Truenetwork, Russian Federation.