VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package QRAGadget

Package {QRAGadget}


Version: 0.3.0
Title: A 'Shiny' Gadget for Interactive 'QRA' Visualizations
Description: Upload raster data and easily create interactive quantitative risk analysis 'QRA' visualizations. Select from numerous color palettes, base-maps, and different configurations.
URL: https://github.com/paulgovan/qragadget, http://paulgovan.github.io/QRAGadget/
BugReports: https://github.com/paulgovan/qragadget/issues
Depends: R (≥ 2.10.0)
License: Apache License version 1.1 | Apache License version 2.0 [expanded from: Apache License]
Imports: htmlwidgets, leaflet, magrittr, miniUI, raster, scales, shiny, shinyWidgets, sp
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2023-06-23 22:47:52 UTC; paulgovan
Author: Paul Govan ORCID iD [aut, cre, cph]
Maintainer: Paul Govan <pgovan1@aggienetwork.com>
Repository: CRAN
Date/Publication: 2023-06-23 23:50:08 UTC

A 'Shiny' Gadget for Interactive QRA Visualizations.

Description

Upload raster data and easily create interactive QRA visualizations. Select from numerous color palettes, basemaps, and different configurations.

Usage

QRAGadget()

Value

A standalone html file

Examples

if (interactive()) {
  QRAGadget()
}


Matrix input

Description

Creates an adjustable-length matrix input.

Usage

matrixInput(inputId, label, data)

Arguments

inputId

Input variable to assign the control's value to.

label

Display label for the control.

data

The initial values to use for the matrix.

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.